Template Tags — django-critic v0.2.1 documentation

django-critic v0.2.1 documentation

# Template Tags

- Table of Contents
- index
  previous

# Template Tags

## critic_user_rating

Retrieves the user’s rating for a specified object

Syntax

    {% critic_user_rating [object] as [varname] %}

Example

    {% critic_user_rating story as user_rating %}

        You have rated this story a {{ user_rating }}

## critic_render

Renders some template for a specific object.

Syntax

    {% critic_render [object] %}

Example

    {% critic_render entry %}

## critic_render_url

When given a object, a url for rendering the rating method will be returned. This is simply here for convenience.

Syntax

    {% critic_render_url [object] %}

Example

    {% critic_render_url [object] %}

Output Example

    /critic/render/11/2/